# Boundary conditions
The temperature $\theta$ inside the geometrical object is driven by 
1. the material properties and the initial temperature and
2. the heat flux along the geometrical boundary sides.

We denote the heat flux
- inwards the object as **induced** heat flux $\Phi_{in}$ and
- outwards the object as **emitted** heat flux $\Phi_{out}$ (**Emission**).

Mathematically spoken, the situation on the boundary sides are described here by [Neumann](https://en.wikipedia.org/wiki/Neumann_boundary_condition) or [Robin boundary conditions](https://en.wikipedia.org/wiki/Neumann_boundary_condition). On boundary sides where actuators (e.g. heating elements) are assumed, we have

$\left[\lambda(\theta) \nabla \theta(t,x) \right] ~ \vec{n} = \Phi_{in}(t,x) + \Phi_{out}(t,x)$

with outer normal vector $\vec{n}$.

## Emitted heat flux / Emissions

The emissions are described by 
- linear heat transfer / convection  
$-h (\theta - \theta_{amb})$

- and nonlinear heat radiation
$- \epsilon ~ \sigma (\theta - \theta_{amb})$

with ambient temperature (temperature of the object's surounding) $\theta_{amb}$, heat transfer coefficient $h>0$, [emissivity](https://en.wikipedia.org/wiki/Emissivity) $\epsilon \in [0,1]$ and [Stefan-Boltzmann constant](https://en.wikipedia.org/wiki/Stefan%E2%80%93Boltzmann_constant) $\sigma$.

Heat transfer coefficient $h$ and emissivity $\epsilon$ can be defined for each boundary side seperately. Internally, the multiplication of emissivity $\epsilon$ and Stefan-Boltzmann constant $\sigma$ is saved as radiation coefficient $k = \epsilon ~ \sigma$.

```@docs
Emission
```

```@docs
createEmission
```

```@docs
emit
```


## Induced heat flux

The induced heat flux is generated by $N_{u}$ [actuators](@ref actuators) that can be placed directly (e.g. heating elements) or indirectly (e.g. laser beam) on each boundary of the geometrical object. All actuators are assumed to have a specific **spatial characterization** $b_{n}(x)$ reaching from 0 to 1 like a scaling from zero to 100%. The control signal $u_{n}(t)$ defines the power intensity of the n-th actuator. So, the induced heat flux is defined by

$\Phi_{in}(t,x) = \sum_{n=1}^{N_{u}} b_{n}(x) ~ u_{n}(t).$